from setuptools import setup, find_packages

setup(
    name='pypdfy',
    version='0.1.1',
    license='MIT',
    description='An easy approach to metadata extraction for PDF files',
    author='David Bros Campillo',
    author_email='david_corp896@outlook.es',
    maintainer='David Bros',
    maintainer_email='david_corp896@outlook.es',
    packages=find_packages(exclude=['README']),
    download_url='https://github.com/TheHunter896/pypdfy',
    keywords=['PDF', 'METADATA', 'NO DEPENDENCIES', 'PYTHON', 'OOP'],
    )